@@ -6,12 +6,12 @@ drop table if exists `ais_basestation`;
 
 create table ais_nmea (
 	id int not null primary key auto_increment,
-	time int, message varchar(200)
+	time bigint, message varchar(200)
 );
 
 create table ais_position (
 	id int not null primary key auto_increment,
-	time int,
+	time bigint,
 	mmsi int,
 	latitude float,
 	longitude float,
@@ -22,7 +22,7 @@ create table ais_position (
 
 create table ais_vesseldata (
 	id int not null primary key auto_increment,
-	time int,
+	time bigint,
 	mmsi int,
 	name varchar(21),
 	destination varchar(21),
@@ -32,7 +32,7 @@ create table ais_vesseldata (
 
 create table ais_basestation (
 	id int not null primary key auto_increment,
-	time int,
+	time bigint,
 	mmsi int,
 	latitude float, longitude float
 );
